#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_DECONV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_DECONV_HPP_INCLUDED

#include <nt2/polynom/include/functions/scalar/deconv.hpp>

#endif
